@@ -1,4 +1,5 @@
 /** aux-templ.c  -  Auxiliary functions template: cloning, freeing, walking data
+ ** Copyright (c) 2010 Sampo Kellomaki (sampo@iki.fi), All Rights Reserved.
  ** Copyright (c) 2006 Symlabs (symlabs@symlabs.com), All Rights Reserved.
  ** Author: Sampo Kellomaki (sampo@iki.fi)
  ** This is confidential unpublished proprietary source code of the author.
@@ -31,22 +32,6 @@
 #define EL_NS     ELNS
 #define EL_TAG    ELTAG
 
-/* FUNC(TXNEW_ELNAME) */
-
-/* Trivial allocator/constructor for the datatype. */
-
-/* Called by: */
-struct ELSTRUCT* TXNEW_ELNAME(struct zx_ctx* c, struct zx_elem_s* father)
-{
-  struct ELSTRUCT* x = ZX_ZALLOC(c, struct ELSTRUCT);
-  x->gg.g.tok = TXELNAME_ELEM;
-  if (father) {
-    x->gg.g.n = &father->kids->g;
-    father->kids = &x->gg;
-  }
-  return x;
-}
-
 #ifdef ZX_ENA_AUX
 
 /* FUNC(TXDUP_STRS_ELNAME) */
