@@ -1,13 +1,14 @@
 /* saml2.h  -  Widely used SAML 2.0 constants
- * Copyright (c) 2006 Symlabs (symlabs@symlabs.com), All Rights Reserved.
+ * Copyright (c) 2006-2008 Symlabs (symlabs@symlabs.com), All Rights Reserved.
  * Author: Sampo Kellomaki (sampo@iki.fi)
  * This is confidential unpublished proprietary source code of the author.
  * NO WARRANTY, not even implied warranties. Contains trade secrets.
  * Distribution prohibited unless authorized in writing.
  * Licensed under Apache License 2.0, see file COPYING.
- * $Id: saml2.h,v 1.2 2006/11/19 06:19:40 sampo Exp $
+ * $Id: saml2.h,v 1.3 2008-04-14 04:23:58 sampo Exp $
  *
  * 26.8.2006, created --Sampo
+ * 14.4.2008, added SimpleSign --Sampo
  */
 
 #ifndef _saml2_h
@@ -78,6 +79,7 @@
 #define SAML2_REDIR    "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect"
 #define SAML2_ART      "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact"
 #define SAML2_POST     "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST"
+#define SAML2_POST_SIMPLE_SIGN "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign"
 #define SAML2_URI      "urn:oasis:names:tc:SAML:2.0:bindings:URI"
 
 /* Attribute types describe how attributes are encoded. */
