@@ -297,7 +297,7 @@ int main(int argc, char** argv, char** env)
   if (drop_gid) if (setgid(drop_gid)) { perror("INIT: setgid"); exit(1); }
   if (drop_uid) if (setuid(drop_uid)) { perror("INIT: setuid"); exit(1); }
   
-  len_so = read_all_fd(0, buf, sizeof(buf)-1, &got_all);
+  len_so = read_all_fd(fileno(stdin), buf, sizeof(buf)-1, &got_all);
   if (got_all <= 0) DIE("Missing data");
   buf[got_all] = 0;
   
