@@ -587,7 +587,7 @@ struct zx_str* zxid_call_epr(zxid_conf* cf, zxid_ses* ses, zxid_epr* epr, const
   env = zxid_wsc_call(cf, ses, epr, env, &ret_enve);
   if (!env) {
     ERR("Parsing return value failed %p", env);
-    D("ret_enve(%s) len=%d", ret_enve, strlen(ret_enve));
+    D("ret_enve(%s) len=%d", ret_enve, (int)strlen(ret_enve));
     D_DEDENT("call: ");
     if (cf->valid_opt & ZXID_VALID_OPT_SKIP_RESP_HDR) {
       ERR("WARNING! Important response security validations disabled by VALID_OPT=0x%x AND Fault occured or parsing return value failed. Pretending success anyway.", cf->valid_opt);
